==> zio-aws-iot1clickdevices_2.13-5.17.123.2-sources.jar: zio/aws/iot1clickdevices/model/InitiateDeviceClaimRequest.scala <==
package zio.aws.iot1clickdevices.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.iot1clickdevices.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class InitiateDeviceClaimRequest(deviceId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot1clickdevices.model.InitiateDeviceClaimRequest = {
    import InitiateDeviceClaimRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot1clickdevices.model.InitiateDeviceClaimRequest
      .builder()
      .deviceId(__string.unwrap(deviceId): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.iot1clickdevices.model.InitiateDeviceClaimRequest.ReadOnly =
    zio.aws.iot1clickdevices.model.InitiateDeviceClaimRequest
      .wrap(buildAwsValue())
}
object InitiateDeviceClaimRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot1clickdevices.model.InitiateDeviceClaimRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot1clickdevices.model.InitiateDeviceClaimRequest =
      zio.aws.iot1clickdevices.model.InitiateDeviceClaimRequest(deviceId)
    def deviceId: __string
    def getDeviceId: ZIO[Any, Nothing, __string] = ZIO.succeed(deviceId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.InitiateDeviceClaimRequest
  ) extends zio.aws.iot1clickdevices.model.InitiateDeviceClaimRequest.ReadOnly {
    override val deviceId: __string =
      zio.aws.iot1clickdevices.model.primitives.__string(impl.deviceId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.InitiateDeviceClaimRequest
  ): zio.aws.iot1clickdevices.model.InitiateDeviceClaimRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-iot1clickdevices_2.13-5.17.201.1-sources.jar: zio/aws/iot1clickdevices/model/InitiateDeviceClaimRequest.scala <==
package zio.aws.iot1clickdevices.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.iot1clickdevices.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class InitiateDeviceClaimRequest(deviceId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot1clickdevices.model.InitiateDeviceClaimRequest = {
    import InitiateDeviceClaimRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot1clickdevices.model.InitiateDeviceClaimRequest
      .builder()
      .deviceId(deviceId: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.iot1clickdevices.model.InitiateDeviceClaimRequest.ReadOnly =
    zio.aws.iot1clickdevices.model.InitiateDeviceClaimRequest
      .wrap(buildAwsValue())
}
object InitiateDeviceClaimRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot1clickdevices.model.InitiateDeviceClaimRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot1clickdevices.model.InitiateDeviceClaimRequest =
      zio.aws.iot1clickdevices.model.InitiateDeviceClaimRequest(deviceId)
    def deviceId: __string
    def getDeviceId: ZIO[Any, Nothing, __string] = ZIO.succeed(deviceId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.InitiateDeviceClaimRequest
  ) extends zio.aws.iot1clickdevices.model.InitiateDeviceClaimRequest.ReadOnly {
    override val deviceId: __string = impl.deviceId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.InitiateDeviceClaimRequest
  ): zio.aws.iot1clickdevices.model.InitiateDeviceClaimRequest.ReadOnly =
    new Wrapper(impl)
}
